@@ -33,13 +33,13 @@ class Model(_AbstractRateModel):
 
     def __init__(
         self,
-        parameters: dict = None,
-        compounds: List[str] = None,
-        algebraic_modules: dict = None,
-        rate_stoichiometries: dict = None,
-        rates: dict = None,
-        functions: dict = None,
-        meta_info: dict = None,
+        parameters: dict[str, float] | None = None,
+        compounds: List[str] | None = None,
+        algebraic_modules: dict | None = None,
+        rate_stoichiometries: dict | None = None,
+        rates: dict | None = None,
+        functions: dict | None = None,
+        meta_info: dict | None = None,
     ):
         BaseModel.__init__(self, meta_info=meta_info)
         CompoundMixin.__init__(self, compounds=compounds)
@@ -154,12 +154,12 @@ class Model(_AbstractRateModel):
 
     def add(
         self,
-        compounds: list = None,
-        parameters: Dict[str, float] = None,
-        algebraic_modules: Dict[str, dict] = None,
-        rates: Dict[str, dict] = None,
-        stoichiometries: Dict[str, dict] = None,
-        functions: Dict[str, Callable] = None,
+        compounds: list[str] | None = None,
+        parameters: Dict[str, float] | None = None,
+        algebraic_modules: Dict[str, dict] | None = None,
+        rates: Dict[str, dict] | None = None,
+        stoichiometries: Dict[str, dict] | None = None,
+        functions: Dict[str, Callable] | None = None,
     ) -> None:
         if compounds is not None:
             self.add_compounds(compounds)
@@ -176,11 +176,11 @@ class Model(_AbstractRateModel):
 
     def update(
         self,
-        parameters: Dict[str, float] = None,
-        algebraic_modules: Dict[str, dict] = None,
-        rates: Dict[str, dict] = None,
-        stoichiometries: Dict[str, dict] = None,
-        functions: Dict[str, Callable] = None,
+        parameters: Dict[str, float] | None = None,
+        algebraic_modules: Dict[str, dict] | None = None,
+        rates: Dict[str, dict] | None = None,
+        stoichiometries: Dict[str, dict] | None = None,
+        functions: Dict[str, Callable] | None = None,
     ) -> None:
         if parameters is not None:
             self.update_parameters(parameters)
@@ -195,12 +195,12 @@ class Model(_AbstractRateModel):
 
     def remove(
         self,
-        compounds: List[str] = None,
-        parameters: List[str] = None,
-        algebraic_modules: List[str] = None,
-        rates: List[str] = None,
-        stoichiometries: List[str] = None,
-        functions: List[str] = None,
+        compounds: List[str] | None = None,
+        parameters: List[str] | None = None,
+        algebraic_modules: List[str] | None = None,
+        rates: List[str] | None = None,
+        stoichiometries: List[str] | None = None,
+        functions: List[str] | None = None,
     ) -> None:
         if compounds is not None:
             self.remove_compounds(compounds)
@@ -224,10 +224,10 @@ class Model(_AbstractRateModel):
         rate_name: str,
         function: Callable[..., float],
         stoichiometry: Dict[str, float],
-        modifiers: List[str] = None,
-        parameters: List[str] = None,
-        dynamic_variables: List[str] = None,
-        args: List[str] = None,
+        modifiers: List[str] | None = None,
+        parameters: List[str] | None = None,
+        dynamic_variables: List[str] | None = None,
+        args: List[str] | None = None,
         reversible: bool = False,
         check_consistency: bool = True,
         **meta_info: Dict[str, Any],
@@ -314,13 +314,13 @@ class Model(_AbstractRateModel):
     def update_reaction(
         self,
         rate_name: str,
-        function: Callable = None,
-        stoichiometry: Dict[str, float] = None,
-        modifiers: List[str] = None,
-        parameters: List[str] = None,
-        dynamic_variables: List[str] = None,
-        args: List[str] = None,
-        reversible: bool = None,
+        function: Callable[..., float] | None = None,
+        stoichiometry: Dict[str, float] | None = None,
+        modifiers: List[str] | None = None,
+        parameters: List[str] | None = None,
+        dynamic_variables: List[str] | None = None,
+        args: List[str] | None = None,
+        reversible: bool | None = None,
         check_consistency: bool = True,
     ) -> None:
         """Update an existing reaction.
