@@ -46,10 +46,10 @@ def Simulator(model: _LinearLabelModel) -> _LinearLabelSimulate:
 def Simulator(
     model: Union[_LabelModel, _LinearLabelModel, _Model],
     integrator: Type[AbstractIntegrator] = default_integrator,
-    y0: Optional[ArrayLike] = None,
-    time: Optional[List[Array]] = None,
-    results: Optional[List[Array]] = None,
-    parameters: List[Dict[str, float]] = None,
+    y0: ArrayLike | None = None,
+    time: List[Array] | None = None,
+    results: List[Array] | None = None,
+    parameters: List[Dict[str, float]] | None = None,
 ) -> Union[_LabelSimulate, _LinearLabelSimulate, _Simulate]:
     """Choose the simulator class according to the model type.
 
